from django.apps import AppConfig


class Oauth2ClientConfig(AppConfig):
    name = 'tendenci.apps.oauth2_client'
